import { BUNDLED_LANGUAGES, BUNDLED_THEMES, getHighlighter } from 'shiki'

const highlighter = await getHighlighter({
    theme: 'nord',
    langs: ['javascript', 'python']
})

// Some code that tells you that you now need `ruby` highlighting
const code = imaginaryCodeThatNeedsRubyHighlighting()
const language = imaginaryLanguageDetection(code)
const newTheme = imaginaryCodeThatDefinesTheTheme()

// Check for the loaded languages, and load the language if it's not loaded yet.
if (!highlighter.getLoadedLanguages().includes(language)) {
    // Check if the language is supported by Shiki
    const bundles = BUNDLED_LANGUAGES.filter((bundle) => {
        // Languages are specified by their id, they can also have aliases (i. e. "js" and "javascript")
        return bundle.id === language || bundle.aliases?.includes(language);
    });
    if (bundles.length > 0) {
        await highlighter.loadLanguage(language)
    } else {
        // Do some error handling or default to another language or...
    }
}

// Check for the loaded themes, and load the theme if it's not loaded yet.
if (!highlighter.getLoadedThemes().includes(newTheme)) {
    // Check if the theme is supported by Shiki
    if (BUNDLED_THEMES.includes(newTheme) {
        await highlighter.loadTheme(newTheme)
    } else {
        // Do some error handling or default to another theme or...
    }
}

window.highlighter = highlighter
